==> m9s_sale_channel-5.2.6-py3-none-any.whl: trytond/modules/sale_channel/user.py <==
# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from trytond.model import fields

from trytond.pyson import Eval
from trytond.pool import PoolMeta, Pool


class User(metaclass=PoolMeta):
    __name__ = "res.user"

    current_channel = fields.Many2One(
        'sale.channel', 'Current Channel', domain=[
            ('id', 'in', Eval('allowed_read_channels', [])),
        ], depends=['allowed_read_channels']
    )

    read_channels = fields.Many2Many(
        'sale.channel-read-res.user', 'user', 'channel', 'Read Channels'
    )
    create_channels = fields.Many2Many(
        'sale.channel-write-res.user', 'user', 'channel', 'Create Channels'
    )
    allowed_read_channels = fields.Function(
        fields.One2Many('sale.channel', None, 'Allowed Read Channels'),
        'get_allowed_channels'
    )

    allowed_create_channels = fields.Function(
        fields.One2Many('sale.channel', None, 'Allowed Create Channels'),
        'get_allowed_channels'
    )

    @classmethod
    def __setup__(cls):
        super(User, cls).__setup__()
        cls._preferences_fields.extend([
            'current_channel',
        ])
        cls._context_fields.insert(0, 'current_channel')
        cls._context_fields.insert(0, 'allowed_read_channels')
        cls._context_fields.insert(0, 'allowed_create_channels')

    def get_default_channel(self):
        Channel = Pool().get('sale.channel')

        channels = Channel.search([
                ('company', '=', self.company),
                ('id', 'in', [c.id for c in self.allowed_read_channels]),
                ])
        if channels:
            return channels[0]
        else:
            return None

    @fields.depends('main_company', 'allowed_read_channels')
    def on_change_main_company(self):
        super(User, self).on_change_main_company()
        self.current_channel = self.get_default_channel()

    @fields.depends('company', 'allowed_read_channels')
    def on_change_company(self):
        super(User, self).on_change_company()
        self.current_channel = self.get_default_channel()

    def get_status_bar(self, name):
        status = super(User, self).get_status_bar(name)
        if self.current_channel:
            status += ' - %s' % (self.current_channel.rec_name)
        return status

    def get_allowed_channels(self, name):
        """
        Return allowed channels
        """
        pool = Pool()
        Channel = pool.get('sale.channel')
        User = pool.get('res.user')
        Model = pool.get('ir.model.data')

        sale_admin_id = Model.get_id('sale', 'group_sale_admin')

        # If user is sale_admin allow read and write on all channels
        if sale_admin_id in User.get_groups():
            return [c.id for c in Channel.search([])]

        if name == 'allowed_read_channels':
            return list(
                set([c.id for c in self.read_channels + self.create_channels]))

        elif name == 'allowed_create_channels':
            return [c.id for c in self.create_channels]

==> m9s_sale_channel-5.2.10-py3-none-any.whl: trytond/modules/sale_channel/user.py <==
# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from trytond.model import fields
from trytond.pool import Pool, PoolMeta
from trytond.pyson import Eval
from trytond.transaction import Transaction


class User(metaclass=PoolMeta):
    __name__ = "res.user"

    current_channel = fields.Many2One('sale.channel', 'Current Channel',
        domain=[
            ('company', '=', Eval('company', -1)),
            ], depends=['company'],
        )

    @classmethod
    def __setup__(cls):
        super(User, cls).__setup__()
        cls._preferences_fields.extend([
            'current_channel',
        ])
        cls._context_fields.insert(0, 'current_channel')

    def get_default_channel(self):
        Channel = Pool().get('sale.channel')

        company_id = (Transaction().context.get('company')
            or self.company and self.company.id)
        channels = Channel.search([
                ('company', '=', company_id),
                ])
        if channels:
            return channels[0]

    @fields.depends('main_company')
    def on_change_main_company(self):
        super(User, self).on_change_main_company()
        self.current_channel = self.get_default_channel()

    @fields.depends('company')
    def on_change_company(self):
        super(User, self).on_change_company()
        self.current_channel = self.get_default_channel()

    def get_status_bar(self, name):
        status = super(User, self).get_status_bar(name)
        if self.current_channel:
            status += ' - %s' % (self.current_channel.name)
        return status
